@@ -473,7 +473,7 @@ typedef unsigned int spif_uint32_t;
  *
  * @see @link DOXGRP_TYPES Portable Data Types @endlink
  */
-typedef signed   long long spif_int64_t;
+typedef signed   long spif_int64_t;
 
 /**
  * A 64-bit unsigned integer.
@@ -482,7 +482,7 @@ typedef signed   long long spif_int64_t;
  *
  * @see @link DOXGRP_TYPES Portable Data Types @endlink
  */
-typedef unsigned long long spif_uint64_t;
+typedef unsigned long spif_uint64_t;
 /*@}*/
 
 /*@{*/
@@ -579,6 +579,15 @@ typedef unsigned long spif_ulong_t;
  */
 typedef spif_char_t *spif_charptr_t;
 
+/**
+ * A pointer to a byte of data.
+ *
+ * A pointer to a byte of data.
+ *
+ * @see @link DOXGRP_TYPES Portable Data Types @endlink
+ */
+typedef spif_uint8_t *spif_byteptr_t;
+
 /**
  * A generic, untyped pointer.
  *
